@@ -8,6 +8,7 @@
 */
 
 #include "dnattributeorderconfigwidget.h"
+
 #include "libkleo_debug.h"
 #include "libkleo/dn.h"
 
@@ -20,9 +21,10 @@
 
 #include <QTreeWidget>
 #include <QHeaderView>
+#include <KLazyLocalizedString>
 
 
-class Kleo::DNAttributeOrderConfigWidget::Private
+class Kleo::DNAttributeOrderConfigWidget::DNAttributeOrderConfigWidgetPrivate
 {
 public:
     enum { UUp = 0, Up = 1, Left = 2, Right = 3, Down = 4, DDown = 5 };
@@ -36,8 +38,6 @@ public:
 #ifndef QT_NO_TREEWIDGET
     QTreeWidgetItem *placeHolderItem = nullptr;
 #endif
-
-    Kleo::DNAttributeMapper *mapper = nullptr;
 };
 
 #ifndef QT_NO_TREEWIDGET
@@ -49,12 +49,9 @@ static void prepare(QTreeWidget *lv)
 }
 #endif
 
-Kleo::DNAttributeOrderConfigWidget::DNAttributeOrderConfigWidget(DNAttributeMapper *mapper, QWidget *parent, Qt::WindowFlags f)
-    : QWidget(parent, f), d(new Private)
+Kleo::DNAttributeOrderConfigWidget::DNAttributeOrderConfigWidget(QWidget *parent, Qt::WindowFlags f)
+    : QWidget(parent, f), d(new DNAttributeOrderConfigWidgetPrivate)
 {
-    Q_ASSERT(mapper);
-    d->mapper = mapper;
-
     auto glay = new QGridLayout(this);
     glay->setContentsMargins(0, 0, 0, 0);
     glay->setColumnStretch(0, 1);
@@ -97,23 +94,23 @@ Kleo::DNAttributeOrderConfigWidget::DNAttributeOrderConfigWidget(DNAttributeMapp
     static const struct {
         const char *icon;
         int row, col;
-        const char *tooltip;
+        const KLazyLocalizedString tooltip;
         void(DNAttributeOrderConfigWidget::*slot)();
         bool autorepeat;
     } navButtons[] = {
-        { "go-top",    0, 1, I18N_NOOP("Move to top"),   &DNAttributeOrderConfigWidget::slotDoubleUpButtonClicked, false },
-        { "go-up",    1, 1, I18N_NOOP("Move one up"),    &DNAttributeOrderConfigWidget::slotUpButtonClicked, true },
-        { "go-previous",  2, 0, I18N_NOOP("Remove from current attribute order"), &DNAttributeOrderConfigWidget::slotLeftButtonClicked, false },
-        { "go-next", 2, 2, I18N_NOOP("Add to current attribute order"), &DNAttributeOrderConfigWidget::slotRightButtonClicked, false },
-        { "go-down",  3, 1, I18N_NOOP("Move one down"),  &DNAttributeOrderConfigWidget::slotDownButtonClicked, true },
-        { "go-bottom",  4, 1, I18N_NOOP("Move to bottom"), &DNAttributeOrderConfigWidget::slotDoubleDownButtonClicked, false }
+        { "go-top",    0, 1, kli18n("Move to top"),   &DNAttributeOrderConfigWidget::slotDoubleUpButtonClicked, false },
+        { "go-up",    1, 1, kli18n("Move one up"),    &DNAttributeOrderConfigWidget::slotUpButtonClicked, true },
+        { "go-previous",  2, 0, kli18n("Remove from current attribute order"), &DNAttributeOrderConfigWidget::slotLeftButtonClicked, false },
+        { "go-next", 2, 2, kli18n("Add to current attribute order"), &DNAttributeOrderConfigWidget::slotRightButtonClicked, false },
+        { "go-down",  3, 1, kli18n("Move one down"),  &DNAttributeOrderConfigWidget::slotDownButtonClicked, true },
+        { "go-bottom",  4, 1, kli18n("Move to bottom"), &DNAttributeOrderConfigWidget::slotDoubleDownButtonClicked, false }
     };
 
     for (unsigned int i = 0; i < sizeof navButtons / sizeof * navButtons; ++i) {
         QToolButton *tb = d->navTB[i] = new QToolButton(this);
         tb->setIcon(QIcon::fromTheme(QLatin1String(navButtons[i].icon)));
         tb->setEnabled(false);
-        tb->setToolTip(i18n(navButtons[i].tooltip));
+        tb->setToolTip(KLocalizedString(navButtons[i].tooltip).toString());
         xlay->addWidget(tb, navButtons[i].row, navButtons[i].col);
         tb->setAutoRepeat(navButtons[i].autorepeat);
         connect(tb, &QToolButton::clicked, this, navButtons[i].slot);
@@ -122,12 +119,9 @@ Kleo::DNAttributeOrderConfigWidget::DNAttributeOrderConfigWidget(DNAttributeMapp
     glay->addLayout(xlay, row, 1);
 }
 
-Kleo::DNAttributeOrderConfigWidget::~DNAttributeOrderConfigWidget()
-{
-    delete d;
-}
+Kleo::DNAttributeOrderConfigWidget::~DNAttributeOrderConfigWidget() = default;
 
-void Kleo::DNAttributeOrderConfigWidget::load()
+void Kleo::DNAttributeOrderConfigWidget::setAttributeOrder(const QStringList &order)
 {
 #ifndef QT_NO_TREEWIDGET
     // save the _X_ item:
@@ -136,8 +130,6 @@ void Kleo::DNAttributeOrderConfigWidget::load()
     d->availableLV->clear();
     d->currentLV->clear();
 
-    const QStringList order = d->mapper->attributeOrder();
-
     // fill the RHS listview:
     QTreeWidgetItem *last = nullptr;
     for (QStringList::const_iterator it = order.begin(); it != order.end(); ++it) {
@@ -149,19 +141,19 @@ void Kleo::DNAttributeOrderConfigWidget::load()
         } else {
             last = new QTreeWidgetItem(d->currentLV, last);
             last->setText(0, attr);
-            last->setText(1, d->mapper->name2label(attr));
+            last->setText(1, DN::attributeNameToLabel(attr));
         }
     }
 
     // fill the LHS listview with what's left:
 
-    const QStringList all = Kleo::DNAttributeMapper::instance()->names();
+    const QStringList all = DN::attributeNames();
     const QStringList::const_iterator end(all.end());
     for (QStringList::const_iterator it = all.begin(); it != end; ++it) {
         if (!order.contains(*it)) {
             auto item = new QTreeWidgetItem(d->availableLV);
             item->setText(0, *it);
-            item->setText(1, d->mapper->name2label(*it));
+            item->setText(1, DN::attributeNameToLabel(*it));
         }
     }
 
@@ -180,26 +172,20 @@ void Kleo::DNAttributeOrderConfigWidget::takePlaceHolderItem()
 #endif
 }
 
-void Kleo::DNAttributeOrderConfigWidget::save() const
+QStringList Kleo::DNAttributeOrderConfigWidget::attributeOrder() const
 {
-#ifndef QT_NO_TREEWIDGET
     QStringList order;
+#ifndef QT_NO_TREEWIDGET
     for (QTreeWidgetItemIterator it(d->currentLV); (*it); ++it) {
         order.push_back((*it)->text(0));
     }
-
-    d->mapper->setAttributeOrder(order);
 #endif
-}
-
-void Kleo::DNAttributeOrderConfigWidget::defaults()
-{
-     qCDebug (LIBKLEO_LOG) << "Sorry, not implemented: Kleo::DNAttributeOrderConfigWidget::defaults()";
+    return order;
 }
 
 void Kleo::DNAttributeOrderConfigWidget::slotAvailableSelectionChanged(QTreeWidgetItem *item)
 {
-    d->navTB[Private::Right]->setEnabled(item);
+    d->navTB[DNAttributeOrderConfigWidgetPrivate::Right]->setEnabled(item);
 }
 
 void Kleo::DNAttributeOrderConfigWidget::slotCurrentOrderSelectionChanged(QTreeWidgetItem *item)
@@ -210,11 +196,11 @@ void Kleo::DNAttributeOrderConfigWidget::slotCurrentOrderSelectionChanged(QTreeW
 void Kleo::DNAttributeOrderConfigWidget::enableDisableButtons(QTreeWidgetItem *item)
 {
 #ifndef QT_NO_TREEWIDGET
-    d->navTB[Private::UUp  ]->setEnabled(item && d->currentLV->itemAbove(item));
-    d->navTB[Private::Up   ]->setEnabled(item && d->currentLV->itemAbove(item));
-    d->navTB[Private::Left ]->setEnabled(item);
-    d->navTB[Private::Down ]->setEnabled(item && d->currentLV->itemBelow(item));
-    d->navTB[Private::DDown]->setEnabled(item && d->currentLV->itemBelow(item));
+    d->navTB[DNAttributeOrderConfigWidgetPrivate::UUp  ]->setEnabled(item && d->currentLV->itemAbove(item));
+    d->navTB[DNAttributeOrderConfigWidgetPrivate::Up   ]->setEnabled(item && d->currentLV->itemAbove(item));
+    d->navTB[DNAttributeOrderConfigWidgetPrivate::Left ]->setEnabled(item);
+    d->navTB[DNAttributeOrderConfigWidgetPrivate::Down ]->setEnabled(item && d->currentLV->itemBelow(item));
+    d->navTB[DNAttributeOrderConfigWidgetPrivate::DDown]->setEnabled(item && d->currentLV->itemBelow(item));
 #endif
 }
 
@@ -341,7 +327,7 @@ void Kleo::DNAttributeOrderConfigWidget::slotRightButtonClicked()
     d->currentLV->insertTopLevelItem(newRightIndex, left);
     left->setSelected(true);
     enableDisableButtons(left);
-    d->navTB[Private::Right]->setEnabled(next);
+    d->navTB[DNAttributeOrderConfigWidgetPrivate::Right]->setEnabled(next);
     if (next) {
         next->setSelected(true);
     }
